==> eBUS_SDK_JAI_Ubuntu-18.04-x86_64-6.4.0-6670.zip: opt/jai/ebus_sdk/Ubuntu-18.04-x86_64/share/doc/sdk/navtreedata.js <==
var NAVTREE =
[
  [ "eBUS SDK API", "index.html", [
    [ "Getting started with the eBUS SDK", "index.html", null ],
    [ "Building and running", "build.html", null ],
    [ "GigE\\ Vision\\ Device\\ Communication\\ Parameters", "devicecommunicationgev.html", null ],
    [ "USB3\\ Vision\\ Device\\ Communication\\ Parameters", "devicecommunicationu3v.html", null ],
    [ "Receiving Data with GigE Vision", "receivingdata.html", null ],
    [ "Receiving Data with USB3 Vision", "receivingdatau3v.html", null ],
    [ "PvStream\\ GigE\\ Vision\\ Parameters", "streamparametersgev.html", null ],
    [ "PvStream\\ USB3\\ Vision\\ Parameters", "streamparametersu3v.html", null ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_i_pv_d_s_source_8h_source.html",
"_pv_pixel_type_8h.html#a4eff2844732aaf702350ce733654cac9a7312f3380835e3802a4d1dca396b772a",
"class_i_pv_d_s_source.html#aa36198e07dc29d7984d78f04c5b86392",
"class_i_pv_soft_device_g_e_v_event_sink.html#a38c7d6ac0f2a79f886c7f53564afaebc",
"class_pv_camera_bridge.html#a78e7509102187ca6232dbcae6cb3d2a9",
"class_pv_device_event_sink.html#a7220fecdda53bee332e632dc4b0ca81b",
"class_pv_gen_browser_wnd.html#a61e5279ec09f21e9e994ef40764870d7",
"class_pv_logger.html#ad87151f01c1ea12bd38520b6f0a1edfd",
"class_pv_streaming_channel_source_default.html#a37ef37733a9a3a5c5a5fc8af67614411",
"functions_func_o.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> eBUS_SDK_JAI_Ubuntu-20.04-x86_64-6.4.0-6670.zip: opt/jai/ebus_sdk/Ubuntu-20.04-x86_64/share/doc/sdk/navtreedata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "eBUS SDK API", "index.html", [
    [ "Getting started with the eBUS SDK", "index.html", null ],
    [ "Building and running", "build.html", null ],
    [ "GigE\\ Vision\\ Device\\ Communication\\ Parameters", "devicecommunicationgev.html", null ],
    [ "USB3\\ Vision\\ Device\\ Communication\\ Parameters", "devicecommunicationu3v.html", null ],
    [ "Receiving Data with GigE Vision", "receivingdata.html", null ],
    [ "Receiving Data with USB3 Vision", "receivingdatau3v.html", null ],
    [ "PvStream\\ GigE\\ Vision\\ Parameters", "streamparametersgev.html", null ],
    [ "PvStream\\ USB3\\ Vision\\ Parameters", "streamparametersu3v.html", null ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_i_pv_d_s_source_8h_source.html",
"_pv_pixel_type_8h.html#a4eff2844732aaf702350ce733654cac9a7312f3380835e3802a4d1dca396b772a",
"class_i_pv_d_s_source.html#aa36198e07dc29d7984d78f04c5b86392",
"class_i_pv_soft_device_g_e_v_event_sink.html#a38c7d6ac0f2a79f886c7f53564afaebc",
"class_pv_camera_bridge.html#a78e7509102187ca6232dbcae6cb3d2a9",
"class_pv_device_event_sink.html#a7220fecdda53bee332e632dc4b0ca81b",
"class_pv_gen_browser_wnd.html#a61e5279ec09f21e9e994ef40764870d7",
"class_pv_logger.html#ad87151f01c1ea12bd38520b6f0a1edfd",
"class_pv_streaming_channel_source_default.html#a37ef37733a9a3a5c5a5fc8af67614411",
"functions_func_q.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
